@@ -1,8 +1,5 @@
 package Dist::Zilla::PluginBundle::BINGOS;
-{
-  $Dist::Zilla::PluginBundle::BINGOS::VERSION = '0.18';
-}
-
+$Dist::Zilla::PluginBundle::BINGOS::VERSION = '0.20';
 # ABSTRACT: BeLike::BINGOS when you build your dists
 
 use Moose;
@@ -18,7 +15,7 @@ sub configure {
     'PodCoverageTests',
     'PkgVersion',
     'GithubMeta',
-    'ReadmeFromPod',
+    'ReadmeAnyFromPod',
     'PodWeaver',
     'Test::Compile',
     'Clean',
@@ -38,13 +35,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::PluginBundle::BINGOS - BeLike::BINGOS when you build your dists
 
 =head1 VERSION
 
-version 0.18
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -71,7 +70,7 @@ following dist.ini:
   tag_regexp = ^(\\d+\\.\\d+)$
   max_age = 1825
 
-  [ReadmeFromPod]
+  [ReadmeAnyFromPod]
   [Test::Compile]
 
   [Clean]
@@ -97,7 +96,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Chris Williams.
+This software is copyright (c) 2015 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
